@@ -1,14 +1,14 @@
 package Class::PObject;
 
-# $Id$
+# PObject.pm,v 1.55 2004/05/20 07:11:26 sherzodr Exp
 
 use strict;
 #use diagnostics;
 use Log::Agent;
 use vars ('$VERSION', '$revision');
 
-$VERSION  = '2.14';
-$revision = '$Revision$';
+$VERSION  = '2.15';
+$revision = '1.55';
 
 # configuring Log::Agent
 logconfig(-level=>$ENV{POBJECT_DEBUG} || 0);
@@ -1023,6 +1023,6 @@ Copyright (c) 2003 Sherzod B. Ruzmetov. All rights reserved.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-$Date$
+2004/05/20 07:11:26
 
 =cut
